@@ -8,3 +8,7 @@ class TimepieceDefaults(object):
     TIMEPIECE_DEFAULT_LOCATION_SLUG = None
 
     TIMEPIECE_PAID_LEAVE_PROJECTS = {}
+
+    TIMEPIECE_ACCOUNTING_EMAILS = []
+
+    TIMEPIECE_EMAILS_USE_HTTPS = True
