@@ -1,16 +1,14 @@
+from timepiece.tests.contracts import *
 from timepiece.tests.crmcontent import *
-from timepiece.tests.general_ledger import *
-from timepiece.tests.hours import *
 from timepiece.tests.invoices import *
 from timepiece.tests.management import *
-from timepiece.tests.payroll import *
 from timepiece.tests.projects import *
 from timepiece.tests.project_list import *
 from timepiece.tests.relationships import *
 from timepiece.tests.reports import *
+from timepiece.tests.schedule import *
 from timepiece.tests.search import *
-from timepiece.tests.tracking.dashboard import *
-from timepiece.tests.tracking.timesheet import *
+from timepiece.tests.tracking import *
 from timepiece.tests.user_settings import *
 from timepiece.tests.utils import *
 from timepiece.tests.template_tags import *
